@@ -2,6 +2,8 @@
 
 import os
 import requests
+import platform
+import subprocess
 
 if(os.environ.get('TRAVIS')!='true'):
     import pygtk
@@ -25,12 +27,15 @@ import signal
 
 from hackernews import HackerNews
 from chrome import Chrome
+from firefox import Firefox
 from version import Version
+from analytics import Analytics
 
 class HackerNewsApp:
     HN_URL_PREFIX = "https://news.ycombinator.com/item?id="
     UPDATE_URL = "https://github.com/captn3m0/hackertray#upgrade"
     ABOUT_URL = "https://github.com/captn3m0/hackertray"
+    MIXPANEL_TOKEN = "51a04e37dad59393c7371407e84a8050"
     def __init__(self, args):
         #Load the database
         home = expanduser("~")
@@ -42,6 +47,9 @@ class HackerNewsApp:
             except ValueError:
                 self.db = set()
 
+        # Setup analytics
+        self.tracker = Analytics(args.dnt, HackerNewsApp.MIXPANEL_TOKEN)
+
         # create an indicator applet
         self.ind = appindicator.Indicator("Hacker Tray", "hacker-tray", appindicator.CATEGORY_APPLICATION_STATUS)
         self.ind.set_status(appindicator.STATUS_ACTIVE)
@@ -89,7 +97,19 @@ class HackerNewsApp:
         self.menu.show()
 
         self.ind.set_menu(self.menu)
-        self.refresh(chrome_data_directory=args.chrome)
+        self.refresh(chrome_data_directory=args.chrome, firefox_data_directory=args.firefox)
+        self.launch_analytics(args)
+
+    def launch_analytics(self, args):
+        # Now that we're all done with the boot, send a beacone home
+        launch_data = vars(args)
+        launch_data['version'] = Version.current()
+        launch_data['platform'] = platform.linux_distribution()
+        try:
+            launch_data['browser'] = subprocess.check_output(["xdg-settings","get","default-web-browser"]).strip()
+        except subprocess.CalledProcessError as e:
+            launch_data['browser'] = "unknown"
+        self.tracker.track('launch', launch_data)
 
     def toggleComments(self, widget):
         """Whether comments page is opened or not"""
@@ -100,11 +120,13 @@ class HackerNewsApp:
         webbrowser.open(HackerNewsApp.UPDATE_URL)
         # Remove the update button once clicked
         self.menu.remove(widget)
+        self.tracker.visit(HackerNewsApp.UPDATE_URL)
 
 
     def showAbout(self, widget):
         """Handle the about btn"""
         webbrowser.open(HackerNewsApp.ABOUT_URL)
+        self.tracker.visit(HackerNewsApp.ABOUT_URL)
 
     #ToDo: Handle keyboard interrupt properly
     def quit(self, widget, data=None):
@@ -117,6 +139,7 @@ class HackerNewsApp:
             file.write(json.dumps(l))
 
         gtk.main_quit()
+        self.tracker.track('quit')
 
     def run(self):
         signal.signal(signal.SIGINT, self.quit)
@@ -137,6 +160,7 @@ class HackerNewsApp:
 
         if self.commentState:
             webbrowser.open(self.HN_URL_PREFIX + widget.hn_id)
+        self.tracker.visit(widget.url)
 
     def addItem(self, item):
         """Adds an item to the menu"""
@@ -151,20 +175,27 @@ class HackerNewsApp:
 
         i.set_active(visited)
         i.url = item['url']
+        tooltip = "{url}\nPosted by {user} {timeago}".format(url=item['url'], user=item['user'], timeago=item['time_ago'])
+        i.set_tooltip_text(tooltip)
         i.signal_id = i.connect('activate', self.open)
         i.hn_id = item['id']
         i.item_id = item['id']
         self.menu.prepend(i)
         i.show()
 
-    def refresh(self, widget=None, no_timer=False, chrome_data_directory=None):
+    def refresh(self, widget=None, no_timer=False, chrome_data_directory=None, firefox_data_directory=None):
 
         """Refreshes the menu """
         try:
+            # Create an array of 20 false to denote matches in History
+            searchResults = [False]*20
             data = list(reversed(HackerNews.getHomePage()[0:20]))
+            urls = [item['url'] for item in data]
             if(chrome_data_directory):
-                urls = [item['url'] for item in data]
-                searchResults = Chrome.search(urls, chrome_data_directory)
+                searchResults = self.mergeBoolArray(searchResults, Chrome.search(urls, chrome_data_directory))
+
+            if(firefox_data_directory):
+                searchResults = self.mergeBoolArray(searchResults, Firefox.search(urls, firefox_data_directory))
 
             #Remove all the current stories
             for i in self.menu.get_children():
@@ -173,10 +204,7 @@ class HackerNewsApp:
 
             #Add back all the refreshed news
             for index, item in enumerate(data):
-                if(chrome_data_directory):
-                    item['history'] = searchResults[index]
-                else:
-                    item['history'] = False
+                item['history'] = searchResults[index]
                 self.addItem(item)
         # Catch network errors
         except requests.exceptions.RequestException as e:
@@ -186,14 +214,21 @@ class HackerNewsApp:
             if not no_timer:
                 gtk.timeout_add(10 * 30 * 1000, self.refresh, widget, no_timer, chrome_data_directory)
 
-        
+    # Merges two boolean arrays, using OR operation against each pair
+    def mergeBoolArray(self, original, patch):
+        for index, var in enumerate(original):
+            original[index] = original[index] or patch[index]
+        return original
 
 def main():
     parser = argparse.ArgumentParser(description='Hacker News in your System Tray')
     parser.add_argument('-v','--version', action='version', version=Version.current())
     parser.add_argument('-c','--comments', dest='comments',action='store_true', help="Load the HN comments link for the article as well")
     parser.add_argument('--chrome', dest='chrome', help="Specify a Google Chrome Profile directory to use for matching chrome history")
+    parser.add_argument('--firefox', dest='firefox', help="Specify a Firefox Profile directory to use for matching firefox history")
+    parser.add_argument('--dnt', dest='dnt',action='store_true', help="Disable all analytics (Do Not Track)")
     parser.set_defaults(comments=False)
+    parser.set_defaults(dnt=False)
     args = parser.parse_args()
     indicator = HackerNewsApp(args)
     indicator.run()
